abacusai.compute_point_info — AbacusAI documentation

# abacusai.compute_point_info

## Classes

`ComputePointInfo` | The compute point info of the organization

## Module Contents

class abacusai.compute_point_info.ComputePointInfo(client, updatedAt=None, last24HoursUsage=None, last7DaysUsage=None, currMonthAvailPoints=None, currMonthUsage=None, lastThrottlePopUp=None, alwaysDisplay=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The compute point info of the organization

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - updatedAt (str) – The last time the compute point info was updated

    - last24HoursUsage (int) – The 24 hours usage of the organization

    - last7DaysUsage (int) – The 7 days usage of the organization

    - currMonthAvailPoints (int) – The current month’s available compute points

    - currMonthUsage (int) – The current month’s usage compute points

    - lastThrottlePopUp (str) – The last time the organization was throttled

    - alwaysDisplay (bool) – Whether to always display the compute point toggle

  updated_at = None
  last_24_hours_usage = None
  last_7_days_usage = None
  curr_month_avail_points = None
  curr_month_usage = None
  last_throttle_pop_up = None
  always_display = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict